@@ -3,6 +3,7 @@ import io
 import logging
 import os
 import sys
+import warnings
 import xml.etree.ElementTree as etree
 
 from diff_cover import DESCRIPTION, VERSION
@@ -11,19 +12,22 @@ from diff_cover.diff_reporter import GitDiffReporter
 from diff_cover.git_diff import GitDiffFileTool, GitDiffTool
 from diff_cover.git_path import GitPathTool
 from diff_cover.report_generator import (
+    GitHubAnnotationsReportGenerator,
     HtmlReportGenerator,
     JsonReportGenerator,
     MarkdownReportGenerator,
     StringReportGenerator,
 )
+from diff_cover.util import open_file
 from diff_cover.violationsreporters.violations_reporter import (
     LcovCoverageReporter,
     XmlCoverageReporter,
 )
 
-HTML_REPORT_HELP = "Diff coverage HTML output"
-JSON_REPORT_HELP = "Diff coverage JSON output"
-MARKDOWN_REPORT_HELP = "Diff coverage Markdown output"
+FORMAT_HELP = "Format to use"
+HTML_REPORT_DEFAULT_PATH = "diff-cover.html"
+JSON_REPORT_DEFAULT_PATH = "diff-cover.json"
+MARKDOWN_REPORT_DEFAULT_PATH = "diff-cover.md"
 COMPARE_BRANCH_HELP = "Branch to compare"
 CSS_FILE_HELP = "Write CSS into an external file"
 FAIL_UNDER_HELP = (
@@ -47,10 +51,23 @@ EXPAND_COVERAGE_REPORT = (
 INCLUDE_UNTRACKED_HELP = "Include untracked files"
 CONFIG_FILE_HELP = "The configuration file to use"
 DIFF_FILE_HELP = "The diff file to use"
+TOTAL_PERCENT_FLOAT_HELP = (
+    "Show total coverage/quality as a float rounded to 2 decimal places"
+)
 
 LOGGER = logging.getLogger(__name__)
 
 
+def format_type(value):
+    """
+    Accepts:
+        --format html:path/to/file.html,json:path/to/file.json
+
+        return: dict of strings to paths
+    """
+    return dict((item.split(":", 1) for item in value.split(",")) if value else {})
+
+
 def parse_coverage_args(argv):
     """
     Parse command line arguments, returning a dict of
@@ -69,27 +86,13 @@ def parse_coverage_args(argv):
     """
     parser = argparse.ArgumentParser(description=DESCRIPTION)
 
-    parser.add_argument("coverage_file", type=str, help=COVERAGE_FILE_HELP, nargs="+")
+    parser.add_argument("coverage_files", type=str, help=COVERAGE_FILE_HELP, nargs="+")
 
     parser.add_argument(
-        "--html-report",
-        metavar="FILENAME",
-        type=str,
-        help=HTML_REPORT_HELP,
-    )
-
-    parser.add_argument(
-        "--json-report",
-        metavar="FILENAME",
-        type=str,
-        help=JSON_REPORT_HELP,
-    )
-
-    parser.add_argument(
-        "--markdown-report",
-        metavar="FILENAME",
-        type=str,
-        help=MARKDOWN_REPORT_HELP,
+        "--format",
+        type=format_type,
+        default="",
+        help=FORMAT_HELP,
     )
 
     parser.add_argument(
@@ -181,6 +184,12 @@ def parse_coverage_args(argv):
     )
 
     parser.add_argument("--diff-file", type=str, default=None, help=DIFF_FILE_HELP)
+    parser.add_argument(
+        "--total-percent-float",
+        action="store_true",
+        default=None,
+        help=TOTAL_PERCENT_FLOAT_HELP,
+    )
 
     defaults = {
         "show_uncovered": False,
@@ -194,6 +203,7 @@ def parse_coverage_args(argv):
         "diff_range_notation": "...",
         "quiet": False,
         "expand_coverage_report": False,
+        "total_percent_float": False,
     }
 
     return get_config(parser=parser, argv=argv, defaults=defaults, tool=Tool.DIFF_COVER)
@@ -203,10 +213,8 @@ def generate_coverage_report(
     coverage_files,
     compare_branch,
     diff_tool,
-    html_report=None,
+    report_formats=None,
     css_file=None,
-    json_report=None,
-    markdown_report=None,
     ignore_staged=False,
     ignore_unstaged=False,
     include_untracked=False,
@@ -216,6 +224,7 @@ def generate_coverage_report(
     quiet=False,
     show_uncovered=False,
     expand_coverage_report=False,
+    total_percent_float=False,
 ):
     """
     Generate the diff coverage report, using kwargs from `parse_args()`.
@@ -240,37 +249,61 @@ def generate_coverage_report(
         for coverage_file in coverage_files
         if not coverage_file.endswith(".xml")
     ]
-    if len(xml_roots) > 0 and len(lcov_roots) > 0:
-        raise ValueError(f"Mixing LCov and XML reports is not supported yet")
-    elif len(xml_roots) > 0:
+    if xml_roots and lcov_roots:
+        raise ValueError("Mixing LCov and XML reports is not supported yet")
+    if xml_roots:
         coverage = XmlCoverageReporter(xml_roots, src_roots, expand_coverage_report)
     else:
         coverage = LcovCoverageReporter(lcov_roots, src_roots)
 
     # Build a report generator
-    if html_report is not None:
+    if "html" in report_formats:
+        html_report = report_formats["html"] or HTML_REPORT_DEFAULT_PATH
         css_url = css_file
         if css_url is not None:
             css_url = os.path.relpath(css_file, os.path.dirname(html_report))
-        reporter = HtmlReportGenerator(coverage, diff, css_url=css_url)
-        with open(html_report, "wb") as output_file:
+        reporter = HtmlReportGenerator(
+            coverage, diff, css_url=css_url, total_percent_float=total_percent_float
+        )
+        with open_file(html_report, "wb") as output_file:
             reporter.generate_report(output_file)
         if css_file is not None:
             with open(css_file, "wb") as output_file:
                 reporter.generate_css(output_file)
 
-    if json_report is not None:
-        reporter = JsonReportGenerator(coverage, diff)
-        with open(json_report, "wb") as output_file:
+    if "json" in report_formats:
+        json_report = report_formats["json"] or JSON_REPORT_DEFAULT_PATH
+        reporter = JsonReportGenerator(
+            coverage, diff, total_percent_float=total_percent_float
+        )
+        with open_file(json_report, "wb") as output_file:
             reporter.generate_report(output_file)
 
-    if markdown_report is not None:
-        reporter = MarkdownReportGenerator(coverage, diff)
-        with open(markdown_report, "wb") as output_file:
+    if "markdown" in report_formats:
+        markdown_report = report_formats["markdown"] or MARKDOWN_REPORT_DEFAULT_PATH
+        reporter = MarkdownReportGenerator(
+            coverage, diff, total_percent_float=total_percent_float
+        )
+        with open_file(markdown_report, "wb") as output_file:
             reporter.generate_report(output_file)
 
+    if "github-annotations" in report_formats:
+        # Github annotations are always written to stdout, but we can use different types
+        reporter = GitHubAnnotationsReportGenerator(
+            coverage,
+            diff,
+            report_formats["github-annotations"],
+            total_percent_float=total_percent_float,
+        )
+        reporter.generate_report(sys.stdout.buffer)
+
     # Generate the report for stdout
-    reporter = StringReportGenerator(coverage, diff, show_uncovered)
+    reporter = StringReportGenerator(
+        coverage,
+        diff,
+        show_uncovered,
+        total_percent_float=total_percent_float,
+    )
     output_file = io.BytesIO() if quiet else sys.stdout.buffer
 
     # Generate the report
@@ -278,6 +311,53 @@ def generate_coverage_report(
     return reporter.total_percent_covered()
 
 
+def handle_old_format(description, argv):
+    parser = argparse.ArgumentParser(description=description)
+    arg_html = parser.add_argument("--html-report", type=str)
+    arg_json = parser.add_argument("--json-report", type=str)
+    arg_markdown = parser.add_argument("--markdown-report", type=str)
+    parser.add_argument("--format", type=str)
+
+    known_args, unknown_args = parser.parse_known_args(argv)
+    format_ = format_type(known_args.format)
+    if known_args.html_report:
+        if "html" in format_:
+            raise argparse.ArgumentError(
+                arg_html, "Cannot use along with --format html."
+            )
+        warnings.warn(
+            "The --html-report option is deprecated. "
+            f"Use --format html:{known_args.html_report} instead."
+        )
+        format_["html"] = known_args.html_report
+    if known_args.json_report:
+        if "json" in format_:
+            raise argparse.ArgumentError(
+                arg_json, "Cannot use along with --format json."
+            )
+        warnings.warn(
+            "The --json-report option is deprecated. "
+            f"Use --format json:{known_args.json_report} instead."
+        )
+        format_["json"] = known_args.json_report
+    if known_args.markdown_report:
+        if "markdown" in format_:
+            raise argparse.ArgumentError(
+                arg_markdown, "Cannot use along with --format markdown."
+            )
+        warnings.warn(
+            "The --markdown-report option is deprecated. "
+            f"Use --format markdown:{known_args.markdown_report} instead."
+        )
+        format_["markdown"] = known_args.markdown_report
+    if format_:
+        unknown_args += [
+            "--format",
+            ",".join(f"{k}:{v}" for k, v in format_.items()),  # noqa: E231
+        ]
+    return unknown_args
+
+
 def main(argv=None, directory=None):
     """
     Main entry point for the tool, script installed via pyproject.toml
@@ -287,7 +367,7 @@ def main(argv=None, directory=None):
     0 is successful run
     """
     argv = argv or sys.argv
-    arg_dict = parse_coverage_args(argv[1:])
+    arg_dict = parse_coverage_args(handle_old_format(DESCRIPTION, argv[1:]))
 
     quiet = arg_dict["quiet"]
     level = logging.ERROR if quiet else logging.WARNING
@@ -305,12 +385,10 @@ def main(argv=None, directory=None):
         diff_tool = GitDiffFileTool(arg_dict["diff_file"])
 
     percent_covered = generate_coverage_report(
-        arg_dict["coverage_file"],
+        arg_dict["coverage_files"],
         arg_dict["compare_branch"],
         diff_tool,
-        html_report=arg_dict["html_report"],
-        json_report=arg_dict["json_report"],
-        markdown_report=arg_dict["markdown_report"],
+        report_formats=arg_dict["format"],
         css_file=arg_dict["external_css_file"],
         ignore_staged=arg_dict["ignore_staged"],
         ignore_unstaged=arg_dict["ignore_unstaged"],
@@ -321,6 +399,7 @@ def main(argv=None, directory=None):
         quiet=quiet,
         show_uncovered=arg_dict["show_uncovered"],
         expand_coverage_report=arg_dict["expand_coverage_report"],
+        total_percent_float=arg_dict["total_percent_float"],
     )
 
     if percent_covered >= fail_under:
