@@ -9,6 +9,7 @@ import re
 from abc import ABC, abstractmethod
 
 from diff_cover.git_diff import GitDiffError
+from diff_cover.util import to_unix_path, to_unix_paths
 
 
 class BaseDiffReporter(ABC):
@@ -85,7 +86,7 @@ class BaseDiffReporter(ABC):
         include = self._include
         if include:
             for pattern in include:
-                if path in glob.glob(pattern, recursive=True):
+                if path in to_unix_paths(glob.glob(pattern, recursive=True)):
                     break  # file is included
             else:
                 return True
@@ -200,7 +201,7 @@ class GitDiffReporter(BaseDiffReporter):
 
         # Look up the modified lines for the source file
         # If no lines modified, return an empty list
-        return diff_dict.get(src_path, [])
+        return diff_dict.get(to_unix_path(src_path), [])
 
     def _get_included_diff_results(self):
         """
@@ -237,12 +238,13 @@ class GitDiffReporter(BaseDiffReporter):
                 diff_dict = self._parse_diff_str(diff_str)
 
                 for src_path, (added_lines, deleted_lines) in diff_dict.items():
+                    src_path = to_unix_path(src_path)
                     if not self._validate_path_to_diff(src_path):
                         continue
 
                     # Remove any lines from the dict that have been deleted
                     # Include any lines that have been added
-                    result_dict[src_path] = [
+                    result_dict[to_unix_path(src_path)] = [
                         line
                         for line in result_dict.get(src_path, [])
                         if line not in deleted_lines
@@ -332,6 +334,7 @@ class GitDiffReporter(BaseDiffReporter):
 
         # Parse the diff string into sections by source file
         for line in diff_str.split("\n"):
+            line = line.rstrip()
             # If the line starts with "diff --git"
             # or "diff --cc" (in the case of a merge conflict)
             # then it is the start of a new source file
@@ -349,22 +352,20 @@ class GitDiffReporter(BaseDiffReporter):
 
             # Every other line is stored in the dictionary for this source file
             # once we find a hunk section
-            else:
-                # Only add lines if we're in a hunk section
-                # (ignore index and files changed lines)
-                if found_hunk or line.startswith("@@"):
-                    # Remember that we found a hunk
-                    found_hunk = True
+            # Only add lines if we're in a hunk section
+            # (ignore index and files changed lines)
+            elif found_hunk or line.startswith("@@"):
+                # Remember that we found a hunk
+                found_hunk = True
 
-                    if src_path is not None:
-                        source_dict[src_path].append(line)
+                if src_path is not None:
+                    source_dict[src_path].append(line)
 
-                    else:
-                        # We tolerate other information before we have
-                        # a source file defined, unless it's a hunk line
-                        if line.startswith("@@"):
-                            msg = f"Hunk has no source file: '{line}'"
-                            raise GitDiffError(msg)
+                # We tolerate other information before we have
+                # a source file defined, unless it's a hunk line
+                elif line.startswith("@@"):
+                    msg = f"Hunk has no source file: '{line}'"
+                    raise GitDiffError(msg)
 
         return source_dict
 
@@ -484,9 +485,9 @@ class GitDiffReporter(BaseDiffReporter):
                 try:
                     return int(groups[0])
 
-                except ValueError:
+                except ValueError as e:
                     msg = f"Could not parse '{groups[0]}' as a line number"
-                    raise GitDiffError(msg)
+                    raise GitDiffError(msg) from e
 
             else:
                 msg = f"Could not find start of hunk in line '{line}'"
@@ -503,7 +504,7 @@ class GitDiffReporter(BaseDiffReporter):
         number is included once and the lines are ordered sequentially.
         """
 
-        if len(line_numbers) == 0:
+        if not line_numbers:
             return []
 
         # Ensure lines are unique by putting them in a set
